# Getting Support

We are glad that you want to use `message_ix` and sorry to hear that you are running into issues!
This page aims to showcase various ways to get support for when you feel stuck.

If you want to learn more about how `message_ix` works, from the ideas behind it to the meanings of every single parameter, please refer to [our documentation](#our-documentation) first.

If you conclude that these are not enough and you have a specific question, please check if [our GitHub discussions](#github-discussions) have got you covered.

If you encounter an issue using `message_ix` as you envisioned, please let us know using [our GitHub issues](#github-issues).

If you have exhausted all previous options *and* collaborate with IIASA, you may also reach out to us on [Slack](#slack).

## Our Documentation

We offer extensive documentation for how `message_ix` works and encourage all new contributions to provide new documentation, too.
Please find our documentation at https://docs.messageix.org/.
Please note the search bar on the left side, and try to use it!
It is a fast and reliable way to find what you are looking for.

## GitHub Discussions

We always welcome new discussion posts on GitHub.
Collecting them all in one place allows other users to find and interact with existing discussions rather than all having to start from scratch.
Please visit https://github.com/iiasa/message_ix/discussions for a list of all past discussions.
You can search them for keywords or scroll through them by category.
If you don't find your particular point of interest addressed already, please [start a new discussion](https://github.com/iiasa/message_ix/discussions/new/choose) by selecting the category that you think is fitting.
We strive to answer as quickly as we can, but may take a few days to get back to you if we are extremely pre-occupied.
Please come back to any discussion you opened to select the answer that finally helped you solve your question.

## GitHub Issues

We appreciate your efforts to tell us that something is not working as intended!
Please head over to https://github.com/iiasa/message_ix/issues and search the existing issues to see if your issue has already been reported.
If no one encountered it before you, please [open a new issue](https://github.com/iiasa/message_ix/issues/new/choose) by completing the form as best you can.
We strive to respond as quickly as we can, but may take a few days to get back to you if we are extremely pre-occupied.

## Slack

This option is only available if you collaborate with IIASA in one form or the other.
And even then, it should only be used after the other resources have been exhausted.
Ask your collaboration contact at IIASA to invite you to Slack, if they have not done so already.
On Slack, please navigate to the `message` "External Connection" in the "IIASA ECE Program".
There, you can search past posts, or post your new topic as usual. 
